==> sagcad-0.9.4.tar.gz: sagcad-0.9.4/src/DrawArea.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : DrawArea.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2003/02/07
 *    Last                 : 2003/02/07
 * ====================================================================
 */
#ifndef __DRAWAREA_H__
#define __DRAWAREA_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */



/* -------------------------------------------------------
 * 1 :   (struct #define etc)
 * -------------------------------------------------------
 */
#define PICTURE_WIDTH  600
#define PICTURE_HEIGHT 500



/* -------------------------------------------------------
 * 2 : ѿ (global)
 * -------------------------------------------------------
 */
#ifdef _DRAWAREA_
#define   GLOBAL
// 
#define   GLOBAL_VAL(v)  = (v)
#else
#define   GLOBAL	extern
// ʬ̵
#define   GLOBAL_VAL(v)  /* */
#endif




#undef  GLOBAL
#undef  GLOBAL_VAL
#undef _DRAWAREA_



/* -------------------------------------------------------
 * 3 : ؿ (Function)
 * -------------------------------------------------------
 */
int configure_event(GtkWidget *widget, GdkEventConfigure *event);
int expose_event(GtkWidget *widget, GdkEventExpose *event);
int motion_notify_event(GtkWidget *widget, GdkEventMotion *event);
int button_press_event(GtkWidget *widget, GdkEventButton *event);
//void draw_charactor(GtkWidget *widget, double x, double y);
GtkWidget *create_drawing_area(void);



#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __DRAWAREA_H__ */
/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : SagCAD
 *    Source               : DrawArea.h
 * ====================================================================
 */

==> sagcad-0.9.5.tar.gz: sagcad-0.9.5/src/DrawArea.h <==
/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 * 
 *    Project              : SagCAD
 *    Description          : CAD/CAM
 *    Source               : DrawArea.h
 * 
 *    ----------------------------------
 * 
 *    License              : GNU General Public License (GPL)
 *    Copyright            : (C) 1998-2003 by Yutaka Sagiya
 *    email                : kappa@a6s.highway.ne.jp
 *                         : yutaka@sagiya.com
 *    Begin                : 2003/02/07
 *    Last                 : 2003/02/07
 * ====================================================================
 */
#ifndef __DRAWAREA_H__
#define __DRAWAREA_H__

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */



/* -------------------------------------------------------
 * 1 :   (struct #define etc)
 * -------------------------------------------------------
 */
#define PICTURE_WIDTH  600
#define PICTURE_HEIGHT 500

#define MOUSE_MOTION_NOTIFY   1
#define MOUSE_PRESS           2
#define MOUSE_RELEASE         4
#define MOUSE_WHEEL_UP         8
#define MOUSE_WHEEL_DOWN       16


/* -------------------------------------------------------
 * 2 : ѿ (global)
 * -------------------------------------------------------
 */
#ifdef _DRAWAREA_
#define   GLOBAL
// 
#define   GLOBAL_VAL(v)  = (v)
#else
#define   GLOBAL	extern
// ʬ̵
#define   GLOBAL_VAL(v)  /* */
#endif




#undef  GLOBAL
#undef  GLOBAL_VAL
#undef _DRAWAREA_



/* -------------------------------------------------------
 * 3 : ؿ (Function)
 * -------------------------------------------------------
 */
int configure_event(GtkWidget *widget, GdkEventConfigure *event);
int expose_event(GtkWidget *widget, GdkEventExpose *event);
int motion_notify_event(GtkWidget *widget, GdkEventMotion *event);
int button_press_event(GtkWidget *widget, GdkEventButton *event);
//void draw_charactor(GtkWidget *widget, double x, double y);
GtkWidget *create_drawing_area(void);

gint Pan(GtkWidget *widget, gint event, gint Button, gint WithButton, gint x, gint y);
gint MouseEvent(GtkWidget *widget, GdkEvent *event, gint i_event, gint Button, gint WithButton, gint x, gint y);


#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __DRAWAREA_H__ */
/* ====================================================================
 * ===  Copyright (C) 1998-2003 Yutaka Sagiya. All rights reserved. ===
 * ====================================================================
 *    Project              : SagCAD
 *    Source               : DrawArea.h
 * ====================================================================
 */
